<div align="center">
    <img src="https://raw.githubusercontent.com/neptune-ai/neptune-client/assets/readme/Github-cover-022025.png" width="1500" />
 <h1>neptune.ai</h1>
</div>

<div align="center">
  <a href="https://neptune.ai/">Website</a>
  <span>&nbsp;&nbsp;•&nbsp;&nbsp;</span>
  <a href="https://docs.neptune.ai/">Docs</a>
  <span>&nbsp;&nbsp;•&nbsp;&nbsp;</span>
  <a href="https://neptune.ai/blog">Blog</a>
&nbsp;
  <hr />
</div>

> [!IMPORTANT]
> This is the Python client for Neptune app version `2.x`.<br/>
> For the new Neptune client, go to **[neptune-client-scale &rarr;][client]**

> [!NOTE]
> For Neptune `2.x` setup and instructions, see the [documentation][legacy-setup].
<hr />

&nbsp;


[client]: https://github.com/neptune-ai/neptune-client-scale
[legacy-setup]: https://docs-legacy.neptune.ai/setup
